/*
 * Author: atotic
 * Created: Jul 29, 2003
 * License: Common Public License v1.0
 */
package org.python.pydev.ui;

/**
 * Miscellaneous UI strings
 */
public class UIConstants {
// Outline view
	public static final String CLASS_ICON = "icons/class_obj.gif";
	public static final String IMPORT_ICON = "icons/imp_obj.gif";
	public static final String IMPORTS_ICON = "icons/impc_obj.gif";
	public static final String BUILTINS_ICON = "icons/builtin_obj.gif";
	public static final String PRIVATE_METHOD_ICON = "icons/methpri_obj.gif";
	public static final String PUBLIC_METHOD_ICON = "icons/methpub_obj.gif";
	public static final String PUBLIC_ATTR_ICON = "icons/attrpub_obj.gif";
	public static final String MAIN_FUNCTION_ICON = "icons/mainfunction.gif";
    public static final String COMPLETION_PACKAGE_ICON = "icons/package_obj.gif";
	public static final String COMPLETION_TEMPLATE = "icons/template.gif";
    public static final String COMMENT = "icons/python_comment.png";
    public static final String COMMENT_BLACK = "icons/python_comment_black.png";

// Actions
	public static final String ALPHA_SORT = "icons/alphab_sort_co.gif";
	public static final String COLLAPSE_ALL = "icons/collapseall.gif";
	public static final String EXPAND_ALL = "icons/expand.gif";
	
//file content
	public static final String FILE_ICON = "icons/file.gif";
	public static final String FOLDER_ICON = "icons/folder.gif";
	public static final String COPY_ICON = "icons/copy.gif";
	public static final String CLOSE_ICON = "icons/close.gif";
    public static final String SOURCE_FOLDER_ICON = "icons/packagefolder_obj.gif";
	
//completion
	public static final String COMPLETION_IMPORT_ICON = "icons/imp_obj.gif";
	public static final String COMPLETION_RELATIVE_IMPORT_ICON = "icons/imp_rel_obj.gif";
	public static final String COMPLETION_CLASS_ICON = "icons/class_obj.gif";
	public static final String COMPLETION_PARAMETERS_ICON = "icons/parameters_obj.gif";

//content assist
	public static final String ASSIST_TRY_EXCEPT = COMPLETION_TEMPLATE;
	public static final String ASSIST_TRY_FINNALLY = COMPLETION_TEMPLATE;

	public static final String ASSIST_NEW_METHOD = "icons/add_correction.gif";
	public static final String ASSIST_NEW_CLASS = "icons/class_obj.gif";
	
	public static final String ASSIST_MOVE_IMPORT = "icons/correction_move.gif";
	    
	public static final String ASSIST_ASSIGN_TO_LOCAL = "icons/methpub_obj.gif";
	public static final String ASSIST_ASSIGN_TO_CLASS = "icons/methpub_obj.gif";
	
	public static final String ASSIST_DOCSTRING = COMPLETION_TEMPLATE;
	
//libraries
	public static final String LIB_SYSTEM_ROOT = "icons/library_obj.gif";
	public static final String LIB_SYSTEM = "icons/jar_l_obj.gif";
	
//general
	public static final String PY_ICON = "icons/python.gif";
	
//browser
	public static final String STOP = "icons/showerr_tsk.gif";
	public static final String REFRESH = "icons/refresh_nav.gif";
	public static final String FORWARD = "icons/forward_nav.gif";
	public static final String BACK = "icons/backward_nav.gif";
	public static final String HOME = "icons/home_nav.gif";
}
